normalize_path_within_workspace

Function normalize_path_within_workspace 

pub fn normalize_path_within_workspace(
    path: &Path,
    workspace_root: &Path,
) -> Result<PathBuf, NormalizePathError>
Normalize path beneath workspace_root while preventing parent traversal escapes.

This function is intended for paths that may not exist yet and therefore cannot be canonicalized directly.